@@ -395,7 +395,7 @@ setMethod("asymptotic_term",signature(yuima="yuima"),
 
 
 	## get d0
-	## required library(adapt)
+	## 
 
 	get.d0.term <- function(){
 
@@ -421,7 +421,7 @@ setMethod("asymptotic_term",signature(yuima="yuima"),
 
 			tmp <- integrate(gz_pi02,mu-7*sqrt(Sigma),mu+7*sqrt(Sigma))$value
 
-		}else if( 2 <= k.size || k.size <= 20 ){	# use library 'adapt' to solve multi-dimentional integration
+		}else if( 2 <= k.size || k.size <= 20 ){	# use  'cubature' to solve multi-dimentional integration
 
 			lambda <- eigen(Sigma)$values
 			matA <- eigen(Sigma)$vector
@@ -435,11 +435,11 @@ setMethod("asymptotic_term",signature(yuima="yuima"),
 				upper[k] <- max
 			}
 
-			if(require(cubature)){
+			#if(require(cubature)){
 				tmp <- adaptIntegrate(gz_pi0, lowerLimit=lower,upperLimit=upper)$integral
-			} else {
-				tmp <- NA		
-			}
+		#	} else {
+	#			tmp <- NA		
+#			}
 
 		}else{
 			stop("length k is too big.")
@@ -744,7 +744,7 @@ setMethod("asymptotic_term",signature(yuima="yuima"),
 	}
 
 	# calculate d1
-	## required library(adapt)
+	## 
 
 	get.d1.term<- function(){
 
